#include "screenselector.h"
#include <QHistoryState>
#include <QRegularExpression>


ScreenSelector::ScreenSelector(QObject *parent)
    : QObject{parent}
{

    QState *working = new QState(); //This is a super State
    working->setObjectName("working");

    QState *loggedInstate = new QState(working);
    loggedInstate->setObjectName("loggedIn");
    loggedInstate->assignProperty(this, "currentScreen",
                                  QUrl("CoolApplication.qml"));

    QState *loggedOutState = new QState(working);
    loggedOutState->setObjectName("loggedOut");
    loggedOutState->assignProperty(this, "currentScreen",
                                   QUrl("LoginScreen.qml"));

    QHistoryState *workingh = new QHistoryState(working);
    working->setInitialState(loggedOutState);

    QState *screnSaverMode = new QState();
    screnSaverMode->setObjectName("screnSaverMode");
    screnSaverMode->assignProperty(this, "currentScreen",
                                   QUrl("Screensaver.qml"));


    working->addTransition(this, &ScreenSelector::inactiveForTooLong,
                           screnSaverMode);
    screnSaverMode->addTransition(this, &ScreenSelector::wokenUp,
                                  workingh);


    loggedOutState->addTransition(&m_communicationLayer,
                                  &CommunicationLayer::loggedIn,
                                  loggedInstate);

    loggedInstate->addTransition(&m_communicationLayer,
                                 &CommunicationLayer::loggedOut,
                                 loggedOutState);


    //Adding States to State Machine
    m_statemachine.addState( working );
    m_statemachine.addState( screnSaverMode );
    m_statemachine.setInitialState( working ) ;

    m_statemachine.start();
}

const QUrl &ScreenSelector::currentScreen() const
{
    return m_currentScreen;
}

void ScreenSelector::setCurrentScreen(const QUrl &newCurrentScreen)
{
    if (m_currentScreen == newCurrentScreen)
        return;
    m_currentScreen = newCurrentScreen;
    emit currentScreenChanged();
}

void ScreenSelector::login()
{
    m_communicationLayer.login();

}

void ScreenSelector::logout()
{

    m_communicationLayer.logout();
}

void ScreenSelector::sleep()
{
    emit inactiveForTooLong();
}

void ScreenSelector::wakeUp()
{
    emit wokenUp();
}

QAbstractState *ScreenSelector::getState()
{
   return m_statemachine.findChild<QAbstractState*>();
}

